@@ -2,8 +2,8 @@
 
 set -ex
 
-if [ $# -ne 3 ]; then
-  echo "Error: 3 parameters are required."
+if [ $# -ne 2 ]; then
+  echo "Error: 2 parameters are required."
   exit 1
 fi
 
@@ -13,7 +13,7 @@ if [ "$1" != "--upstream-version" ]; then
 fi
 
 UPSTREAM_VERSION=$2
-ORIG_TARBALL=$3
+ORIG_TARBALL=`readlink -e ../`/VBoxGuestAdditions_${UPSTREAM_VERSION}.iso
 
 ORGDIR=`pwd`
 
@@ -43,7 +43,7 @@ trap 'rm -r $TMP' EXIT
 mkdir $TMP/${PACKAGE_NAME}-$UPSTREAM_VERSION
 mv $ORIG_TARBALL $TMP/${PACKAGE_NAME}-$UPSTREAM_VERSION/
 cd $TMP
-tar czf ${PACKAGE_NAME}_$UPSTREAM_VERSION.orig.tar.gz ${PACKAGE_NAME}-$UPSTREAM_VERSION
-mv ${PACKAGE_NAME}_$UPSTREAM_VERSION.orig.tar.gz $ORGDIR/../
+tar cJf ${PACKAGE_NAME}_$UPSTREAM_VERSION.orig.tar.xz ${PACKAGE_NAME}-$UPSTREAM_VERSION
+mv ${PACKAGE_NAME}_$UPSTREAM_VERSION.orig.tar.xz $ORGDIR/../
 cd $ORGDIR
-echo "Done, now you can run gbp import-orig ../${PACKAGE_NAME}_$UPSTREAM_VERSION.orig.tar.gz"
+echo "Done, now you can run gbp import-orig ../${PACKAGE_NAME}_$UPSTREAM_VERSION.orig.tar.xz"
